@@ -1,5 +1,6 @@
 from datetime import datetime
 from datetime import timedelta
+from difflib import get_close_matches
 from typing import Iterable
 from typing import List
 from typing import Union
@@ -39,7 +40,21 @@ class ComparisonView(Helper):
     def _get_timezone_name(self, timezone: str) -> str:
         timezone_name = self.timezone_translations.get(timezone.lower())
         if timezone_name is None:
-            raise SystemExit(f'error: {timezone !r} is not an available timezone')
+            error_msg = f'error: {timezone !r} is not an available timezone'
+            possible_matches: List[str] = get_close_matches(
+                timezone,
+                self.timezone_translations,
+                n=5,
+            )
+            if len(possible_matches) == 0:
+                raise SystemExit(error_msg)
+            table = Table()
+            table.add_column('Closest matches')
+            for match in possible_matches:
+                table.add_row(match)
+            self._print_with_rich(error_msg)
+            self._print_with_rich(table)
+            raise SystemExit(1)
         return timezone_name
 
     def _get_headers(self) -> List[str]:
