@@ -9,12 +9,16 @@ from timezone_converter.helper import Helper
 
 
 class ListView(Helper):
+    def __init__(self, letters: List[str]) -> None:
+        self.letters = letters
+
     def _sort_and_group(self) -> DefaultDict[str, List[str]]:
         sorted_timezones = dict(sorted(self.timezone_translations.items()))
         longest_name = len(max(sorted_timezones, key=lambda x: len(x)))
         timezone_groups: DefaultDict[str, List[str]] = defaultdict(list)
         for tz_name in sorted_timezones:
-            timezone_groups[tz_name[0]].append(tz_name.center(longest_name))
+            if tz_name[0] in self.letters:
+                timezone_groups[tz_name[0]].append(tz_name.center(longest_name))
 
         return timezone_groups
 
@@ -26,7 +30,7 @@ class ListView(Helper):
             if timezone_groups[group]
         ]
 
-        return Columns(panels, expand=True)
+        return Columns(panels, expand=False)
 
     def print_columns(self) -> int:
         self._print_with_rich(self._build_columns())
